# encode-utils-cli

> Encode utils collection

[![PyPI version](https://img.shields.io/pypi/v/encode-utils-cli)](https://pypi.org/project/encode-utils-cli)
[![CI/CD](https://github.com/DeadNews/encode-utils-cli/actions/workflows/python-vs-app.yml/badge.svg)](https://github.com/DeadNews/encode-utils-cli/actions/workflows/python-vs-app.yml)
[![pre-commit.ci](https://results.pre-commit.ci/badge/github/DeadNews/encode-utils-cli/main.svg)](https://results.pre-commit.ci/latest/github/DeadNews/encode-utils-cli/main)
[![codecov](https://codecov.io/gh/DeadNews/encode-utils-cli/branch/main/graph/badge.svg?token=OCZDZIYPMC)](https://codecov.io/gh/DeadNews/encode-utils-cli)

## Installation

```sh
pip install encode-utils-cli
# or
pipx install encode-utils-cli
```

## CLI Reference

<https://deadnews.github.io/encode-utils-cli>
